BOOST_PP_CONFIG_EXTENDED_LINE_INFO

The BOOST_PP_CONFIG_EXTENDED_LINE_INFO is a user-defined macro that determines whether BOOST_PP_LINE outputs extended file-iteration state information.

#### Usage

#define BOOST_PP_CONFIG_EXTENDED_LINE_INFO n

#### Arguments

n
  The value that determines if BOOST_PP_LINE outputs extended file-iteration information. This value must be 0 or 1.

#### Remarks

If n is 1, BOOST_PP_LINE will output extended data. By default, this macro is set to 0.

#### See Also

- BOOST_PP_LINE

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)